pub fn select_compressor(_data: &ColumnData) -> BoxedColumnCompressorExpand description
Select the best compressor for a given column based on its type and characteristics
pub fn select_compressor(_data: &ColumnData) -> BoxedColumnCompressorSelect the best compressor for a given column based on its type and characteristics